package service

import "XT_New/models"

type DrugConfig struct {
	ID           int64        `gorm:"column:id" json:"id" form:"id"`
	DrugName     string       `gorm:"column:drug_name" json:"drug_name" form:"drug_name"`
	DrugCategory int64        `gorm:"column:drug_category" json:"drug_category" form:"drug_category"`
	DrugSpec     float64      `gorm:"column:drug_spec" json:"drug_spec" form:"drug_spec"`
	DrugType     int64        `gorm:"column:drug_type" json:"drug_type" form:"drug_type"`
	DrugStatus   string       `gorm:"column:drug_status" json:"drug_status" form:"drug_status"`
	Status       int64        `gorm:"column:status" json:"status" form:"status"`
	OrgId        int64        `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Manufacturer int64        `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	DrugSpecs    []DrugConfig `gorm:"ForeignKey:DrugName;AssociationForeignKey:DrugName" json:"drug_specs"`
}

func (DrugConfig) TableName() string {
	return "xt_base_drug"
}

func GetDrugs(orgId int64) (drugs []*DrugConfig, err error) {
	err = readDb.Model(&DrugConfig{}).Where("org_id = ? AND  status = 1  AND find_in_set('停用',drug_status) = 0", orgId).Preload("DrugSpecs", "status = 1  AND find_in_set('停用',drug_status) = 0 AND org_id = ?", orgId).Group("drug_name").Find(&drugs).Error
	return
}

func FindAllDrugByManufactureId(manufacturer_id int64, dealer_id int64, org_id int64) (goodInfo []*DrugConfig, err error) {
	db := readDb.Model(&DrugConfig{}).Where("org_id = ? AND status = 1 AND find_in_set('停用',drug_status) = 0", org_id)
	if manufacturer_id > 0 {
		db = db.Where("manufacturer = ?", manufacturer_id)
	}
	//if dealer_id > 0 {
	//	db = db.Where("dealer = ?", dealer_id)
	//}
	err = db.Preload("DrugSpecs", "status = 1 AND org_id = ? AND find_in_set('停用',drug_status) = 0", org_id).Group("drug_name").Find(&goodInfo).Error
	return goodInfo, err
}

type MedicineInsuranceDate struct {
	RecordTime int64
}

func GetLastMedicineInsurance(orgID int64, drug_id int64) (mip []*models.MedicineInsurancePercentage, err error) {
	var mip_other models.MedicineInsurancePercentage
	err = readDb.Model(&models.MedicineInsurancePercentage{}).Where("user_org_id = ? AND status=1 AND  drug_id = ?", orgID, drug_id).Last(&mip_other).Error
	err = readDb.Model(&models.MedicineInsurancePercentage{}).Where("user_org_id = ? AND status=1 AND record_time = ? AND drug_id = ?", orgID, mip_other.RecordTime, drug_id).Find(&mip).Error
	return
}
